二、接口说明 — 项目名接口文档 文档

# 二、接口说明

## 2.1、 演示

### 2.1.1、常规参数

说明：参数列举

#### 2.1.1.1、添加

说明：测试post

接口：/demo

方法：POST

参数：

参数 | 类型 | 必须 | 允许值 | 描述
--- | --- | --- | --- | ---
str | string | 否 |  | 手机号
int | integer | 是 | 1, 2 | 整形
float | float | 是 | 1.0, 2.0 | 浮点型
json | json | 是 |  | json格式
form-data | json | 否 |  | 位置：body_json，参数放在body内，以application/json方式，json格式。json类型的参数，设为非必须时，需提供默认值
form-data2 | string | 否 |  | 位置：body_json，参数放在body内，以application/json方式，json格式。json类型的参数，设为非必须时，需提供默认值
body-form | string | 否 |  | 位置：body-form，参数放在body表单内，application/x-body-form-urlencoded方式提交。手机号正则限定
excel | file | 否 |  | 上传文件，参数放在body内，以multipart/form-data方式提交;excel=self.params[“excel”]

成功响应：

    {
       "name": 名称,
       "sex": 姓名,
       "bool_type": true, 类型bool,
       "num": 1.2, 类型float,
       "dict": {
            "a": [
                1,
                ...,
             ],
            "b": [
                {
                  "key": 1,
                },
                ...,
             ],
          },
       "list": [
             {
               "item_x": [
                   {
                     "key_1": value_1,
                     "key_2": value_2,
                   },
                   ...,
                ],
             },
             ...,
          ],

    }

#### 2.1.1.2、查看

说明：测试get

接口：/demo

方法：GET

参数：

参数 | 类型 | 必须 | 允许值 | 描述
--- | --- | --- | --- | ---
_id | str | 否 |  | id
a | integer | 是 |  | 角色id
b | string | 否 |  | 供应商id
d | int | 否 | 1, 2 | 城市全拼列表

成功响应：

    {

    }

### 2.1.2、路径参数

说明：把参数直接放在url里

#### 2.1.2.1、测试路径参数

说明：测试post

接口：/path/(list|abc|[a-f0-9]+|[a-f0-9]{24})

方法：POST

参数：

参数 | 类型 | 必须 | 允许值 | 描述
--- | --- | --- | --- | ---
file | file | 否 |  | form-data模式，可以同时上传多个文件
file2 | file | 否 |  | form-data模式，可以同时上传多个文件
xxx | int | 否 |  | json格式提交
yyy | json | 否 |  | json格式提交

成功响应：

    {

    }

## 2.2、 用户系统

### 2.2.1、未命名

说明：用户

#### 2.2.1.1、添加

说明：测试post

接口：/user

方法：POST

参数：

参数 | 类型 | 必须 | 允许值 | 描述
--- | --- | --- | --- | ---
a | integer | 是 |  | 角色id
b | string | 否 |  | 供应商id
c | string | 否 |  | 手机号
d | int | 否 | 1, 2 | 城市全拼列表
pic | file | 否 |  | 文件

成功响应：

    {
       "name": 名称,
       "sex": 姓名,
       "eeeee": true, 类型bool,
       "num": 1.2, 类型float,
       "dict": {
            "a": [
                1,
                ...,
             ],
            "b": [
                {
                  "fff": 1,
                },
                ...,
             ],
          },
       "list": [
             {
               "a": [
                   {
                     "x": x,
                     "xx": xx,
                   },
                   ...,
                ],
             },
             ...,
          ],

    }

#### 2.2.1.2、查看

说明：测试get

接口：/user

方法：GET

参数：

参数 | 类型 | 必须 | 允许值 | 描述
--- | --- | --- | --- | ---
a | integer | 是 |  | 角色id
b | string | 否 |  | 供应商id
d | int | 否 | 1, 2 | 城市全拼列表

成功响应：

    {

    }

### 2.2.2、userlist

说明：用户列表

#### 2.2.2.1、添加

说明：测试post

接口：/user_list

方法：POST

参数：

参数 | 类型 | 必须 | 允许值 | 描述
--- | --- | --- | --- | ---
a | integer | 是 |  | 角色id
b | string | 否 |  | 供应商id
c | string | 否 |  | 手机号
d | int | 否 | 1, 2 | 城市全拼列表
pic | file | 否 |  | 文件

成功响应：

    {
       "name": 名称,
       "sex": 姓名,
       "dict": {
            "a": 1,
            "b": [
                {
                  "a": 1,
                },
                ...,
             ],
          },
       "list": [
             {
               "a": [
                   {
                     "x": x,
                     "xx": xx,
                   },
                   ...,
                ],
             },
             ...,
          ],

    }

#### 2.2.2.2、查看

说明：测试get

接口：/user_list

方法：GET

参数：

参数 | 类型 | 必须 | 允许值 | 描述
--- | --- | --- | --- | ---
a | integer | 是 |  | 角色id
b | string | 否 |  | 供应商id
d | int | 否 | 1, 2 | 城市全拼列表

成功响应：

    {

    }

## 2.3、 管理员

### 2.3.1、后台管理员

说明：无说明

#### 2.3.1.1、无说明

接口：/admin/member

方法：GET

参数：

参数 | 类型 | 必须 | 允许值 | 描述
--- | --- | --- | --- | ---
uid | int | 是 |  | uid

成功响应：

    {
       "nick_name": 无说明,
       "sex": 1,
       "mobile": 13681236816,
       "state": 1,
       "gid": 1,
       "email": 123@qq.com,

    }

#### 2.3.1.2、无说明

接口：/admin/member

方法：POST

参数：

参数 | 类型 | 必须 | 允许值 | 描述
--- | --- | --- | --- | ---
user_name | str | 是 |  | 无说明
pass_word | str | 是 |  | 无说明，无说明
nick_name | str | 是 |  | 无说明
sex | int | 是 |  | 1 无说明 0 无说明
mobile | str | 是 |  | 无说明
email | str | 是 |  | 无说明
gid | int | 是 |  | 无说明 1 无说明 2 无说明

成功响应：

    {

    }

#### 2.3.1.3、无说明

接口：/admin/member

方法：PUT

参数：

参数 | 类型 | 必须 | 允许值 | 描述
--- | --- | --- | --- | ---
uid | int | 是 |  | 无说明
nick_name | str | 否 |  | 无说明
sex | int | 否 |  | 1 无说明 0 无说明
mobile | str | 否 |  | 无说明
email | str | 否 |  | 无说明
gid | int | 否 |  | 无说明 1 无说明 2 无说明

成功响应：

    {

    }

#### 2.3.1.4、无说明

接口：/admin/member

方法：DELETE

参数：

参数 | 类型 | 必须 | 允许值 | 描述
--- | --- | --- | --- | ---
uid | int | 否 |  | uid

成功响应：

    {

    }

### 2.3.2、无说明

说明：无说明

#### 2.3.2.1、无说明

接口：/admin/login

方法：POST

参数：

参数 | 类型 | 必须 | 允许值 | 描述
--- | --- | --- | --- | ---
user_name | str | 是 |  | 无说明
pass_word | str | 是 |  | 无说明

成功响应：

    {
       "nick_name": 无说明,
       "user_name": name,
       "token": xxxxxxx,
       "sex": 1,
       "mobile": 13681236816,
       "state": 1,
       "gid": 1,
       "uid": 66,
       "_id": str,
       "email": 123@qq.com,

    }

### 2.3.3、无说明

说明：无说明

#### 2.3.3.1、无说明

接口：/admin/resetpwd

方法：POST

参数：

参数 | 类型 | 必须 | 允许值 | 描述
--- | --- | --- | --- | ---
pass_word | str | 是 |  | 无说明
new_pass_word | str | 是 |  | 无说明

成功响应：

    {
       "msg": ok,

    }

### 2.3.4、无说明

#### 2.3.4.1、无说明

说明：无说明（无说明）

接口：/admin/find

方法：POST

参数：

参数 | 类型 | 必须 | 允许值 | 描述
--- | --- | --- | --- | ---
page | str | 是 |  | 无说明

成功响应：

    {
       "data_list": [
             {
               "user_name": 无说明,
               "pass_word": 无说明,
               "nick_name": 无说明,
               "sex": 1,
               "mobile": 无说明,
               "email": 123@qq.com,
               "state": 1,
               "uid": 666,
               "gid": 1,
             },
             ...,
          ],
       "pages": 10,

    }

#### 2.3.4.2、无说明

说明：无说明

接口：/admin/find

方法：GET

参数：

成功响应：

    {
       "data_list": [
             {
               "user_name": 无说明,
               "pass_word": 无说明,
               "nick_name": 无说明,
               "sex": 1,
               "mobile": 无说明,
               "email": 123@qq.com,
               "state": 1,
               "uid": 666,
               "gid": 1,
             },
             ...,
          ],

    }

### 2.3.5、无说明/无说明

#### 2.3.5.1、无说明/无说明

接口：/admin/states

方法：POST

参数：

参数 | 类型 | 必须 | 允许值 | 描述
--- | --- | --- | --- | ---
uid | int | 是 |  | uid
state | int | 是 | 1, -1 | 1 无说明 -1 无说明

成功响应：

    {

    }